<?php

namespace Drupal\ai_provider_aliyun_bailian\Form;

use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\ai\AiProviderPluginManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Aliyun Bailian API access.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Config settings.
   */
  const CONFIG_NAME = 'ai_provider_aliyun_bailian.settings';

  /**
   * The AI provider manager.
   *
   * @var \Drupal\ai\AiProviderPluginManager
   */
  protected $aiProviderManager;

  /**
   * Module Handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a new SettingsForm object.
   */
  final public function __construct(AiProviderPluginManager $ai_provider_manager, ModuleHandlerInterface $module_handler) {
    $this->aiProviderManager = $ai_provider_manager;
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  final public static function create(ContainerInterface $container) {
    return new static(
      $container->get('ai.provider'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'aliyun_bailian_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::CONFIG_NAME,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::CONFIG_NAME);

    $form['api_key'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Aliyun Bailian API Key'),
      '#description' => $this->t('<br />The API Key for Aliyun Bailian service. <br />
      1. Get your API Key from <a href="https://bailian.console.aliyun.com/?tab=model#/api-key" target="_blank">Aliyun Console</a>.<br />
      2. Make sure the API Key has the permission of Qwen.<br />
      3. For models details, check <a href="https://help.aliyun.com/zh/model-studio/models" target="_blank">here</a>. <br />
      4. For models parameter, check <a href="https://help.aliyun.com/zh/model-studio/use-qwen-by-calling-api" target="_blank">here</a>.'),
      '#default_value' => $config->get('api_key'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(static::CONFIG_NAME)
      ->set('api_key', $form_state->getValue('api_key'))
      ->save();

    // Set some defaults.
    $this->aiProviderManager->defaultIfNone('chat', 'aliyun_bailian', 'bailian-v1');
    $this->aiProviderManager->defaultIfNone('chat_with_image_json', 'aliyun_bailian', 'bailian-v1');
    $this->aiProviderManager->defaultIfNone('chat_with_complex_json', 'aliyun_bailian', 'bailian-v1');
    $this->aiProviderManager->defaultIfNone('chat_with_tools', 'aliyun_bailian', 'bailian-v1');
    $this->aiProviderManager->defaultIfNone('chat_with_structured_response', 'aliyun_bailian', 'bailian-v1');

    parent::submitForm($form, $form_state);
  }
}
